@@ -1,21 +1,36 @@
 Logit <-
-function(my.formula, data=d, rows=NULL,
-         digits.d=4, text.width=120, 
+function(my_formula, data=d, rows=NULL,
+         digits_d=4, text_width=120, 
 
          brief=getOption("brief"),
 
-         res.rows=NULL, res.sort=c("cooks","rstudent","dffits","off"), 
-         pred=TRUE, pred.all=FALSE, cooks.cut=1, 
+         res_rows=NULL, res_sort=c("cooks","rstudent","dffits","off"), 
+         pred=TRUE, pred_all=FALSE, cooks_cut=1, 
 
-         X1.new=NULL, X2.new=NULL, X3.new=NULL, X4.new=NULL, 
-         X5.new=NULL, X6.new=NULL, 
+         X1_new=NULL, X2_new=NULL, X3_new=NULL, X4_new=NULL, 
+         X5_new=NULL, X6_new=NULL, 
 
-         pdf.file=NULL, width=5, height=5, ...) {
+         pdf_file=NULL, width=5, height=5, ...) {
  
 
-  if (missing(my.formula)) {
+  # a dot in a parameter name to an underscore
+  dots <- list(...)
+  if (!is.null(dots)) if (length(dots) > 0) {
+    change <- c("digits.d", "text.width", "res.rows", "res.sort", "pred.all",
+                "cooks.cut", "X1.new", "X2.new", "X3.new", "X4.new", 
+                "X5.new", "X6.new", "pdf.file")
+    for (i in 1:length(dots)) {
+      if (names(dots)[i] %in% change) {
+        nm <- gsub(".", "_", names(dots)[i], fixed=TRUE)
+        assign(nm, dots[[i]])
+        get(nm)
+      }
+    }
+  }
+
+  if (missing(my_formula)) {
     cat("\n"); stop(call.=FALSE, "\n","------\n",
-      "Specify a model by listing it first or set according to:  my.formula\n\n")
+      "Specify a model by listing it first or set according to:  my_formula\n\n")
   }
 
 
@@ -47,35 +62,35 @@ function(my.formula, data=d, rows=NULL,
 
 
   # convert character variables to factors (for DV)
-  n.col <- apply(data, 2, function(x) sum(!is.na(x)))  # num values per variable
+  n_col <- apply(data, 2, function(x) sum(!is.na(x)))  # num values per variable
   nu.col <- apply(data, 2, function(x) length(unique(na.omit(x))))  # num unique
   fnu.col <- logical(length=ncol(data))  # logical vector, initial values to FALSE
 
   for (i in 1:ncol(data)) 
-    if (is.character(data[,i])) if (nu.col[i] != n.col[i]) fnu.col[i] <- TRUE 
+    if (is.character(data[,i])) if (nu.col[i] != n_col[i]) fnu.col[i] <- TRUE 
   data[fnu.col] <- lapply(data[fnu.col], as.factor) 
 
   # produce actual argument, such as from an abbreviation, and flag if not exist
-  res.sort <- match.arg(res.sort)
+  res_sort <- match.arg(res_sort)
 
-  max.new <- 6
+  max_new <- 6
 
-  show.R <- FALSE
+  show_R <- FALSE
   explain <- FALSE
 
   old.opt <- options()
   on.exit(options(old.opt))
 
-  options(width=text.width)
+  options(width=text_width)
 
   # output
   cor <- TRUE
 
   if (brief) {
-    if (is.null(res.rows)) res.rows <- 0
+    if (is.null(res_rows)) res_rows <- 0
     pred <- FALSE
     relate <- FALSE
-    show.R <- FALSE
+    show_R <- FALSE
    }
    else relate <- TRUE
       
@@ -93,7 +108,7 @@ function(my.formula, data=d, rows=NULL,
         txtC, "Data frame ", df.name, txtA, "does not exist\n\n", txtB, "\n")
   }
 
-  nm <- all.vars(my.formula)  # names of vars in the model
+  nm <- all.vars(my_formula)  # names of vars in the model
   n.vars <- length(nm)
   n.pred <- n.vars - 1
 
@@ -122,21 +137,21 @@ function(my.formula, data=d, rows=NULL,
       "If a factor, can only have two levels.\n\n")
   }
   
-  if ( !is.null(X1.new)  &&  (n.pred) > max.new ) {
+  if ( !is.null(X1_new)  &&  (n.pred) > max_new ) {
       cat("\n"); stop(call.=FALSE, "\n","------\n",
-        "No new data for prediction if more than", max.new,
+        "No new data for prediction if more than", max_new,
           "predictor variables.\n\n")
   }
 
   # check new.data option for consistency  
   new.data <- FALSE
-  if ( (n.pred) <= max.new ) { 
+  if ( (n.pred) <= max_new ) { 
     for (i in 1:(n.pred)) {
-      pp <- eval(parse(text=paste("X", toString(i),".new",sep="")))
+      pp <- eval(parse(text=paste("X", toString(i),"_new",sep="")))
       if (!is.null(pp)) new.data <- TRUE
     }
     if (new.data) for (i in 1:(n.pred)) {
-      pp <- eval(parse(text=paste("X", toString(i),".new",sep="")))
+      pp <- eval(parse(text=paste("X", toString(i),"_new",sep="")))
       if (is.null(pp)) {
         cat("\n"); stop(call.=FALSE, "\n","------\n",
           "Specified new data values for one predictor variable, so do for all.\n\n")
@@ -163,14 +178,14 @@ function(my.formula, data=d, rows=NULL,
   # logit analysis
   #   all subsequent analysis done on data in model construct lm.out$model
   #   this model construct contains only model vars, with Y listed first
-  lm.out <- glm(my.formula, data=data, family="binomial")
+  lm.out <- glm(my_formula, data=data, family="binomial")
   # -----------------------------------------------------------
 
   n.keep <- nrow(lm.out$model)
     
-  if (is.null(res.rows)) if (n.keep < 20) res.rows <- n.keep else res.rows <- 20 
-  if (res.rows == "all")
-    res.rows <- n.keep  # turn off resids with res.rows=0 call
+  if (is.null(res_rows)) if (n.keep < 20) res_rows <- n.keep else res_rows <- 20 
+  if (res_rows == "all")
+    res_rows <- n.keep  # turn off resids with res_rows=0 call
   
   cat("\n")
   if (sys.nframe() == 1) {  # only accurate if not called from model
@@ -203,7 +218,7 @@ function(my.formula, data=d, rows=NULL,
   for (icol in 1:6) {
     max.num[icol] <- 0 
     for (i in 1:n.vars) {
-      ln.nm <- nchar(as.character(trunc(smc[i,icol]))) + digits.d + 1
+      ln.nm <- nchar(as.character(trunc(smc[i,icol]))) + digits_d + 1
       if (ln.nm > max.num[icol]) max.num[icol] <- ln.nm
     }
     if (max.num[icol] < 9) max.num[icol] <- 9 
@@ -218,13 +233,13 @@ function(my.formula, data=d, rows=NULL,
   cat("\n", rep(" ", buf), est.lbl, ste.lbl, t.lbl, p.lbl, lb.lbl, ub.lbl, sep="", "\n")
   for (i in 1:(nrow(smc))) {
     rlb <- .fmtc(rownames(smc)[i], buf)
-    ub <- .fmt(smc[i,6], digits.d, max.num[6])
-    est <- .fmt(smc[i,1], digits.d, max.num[1])
-    ste <- .fmt(smc[i,2], digits.d, max.num[2]+1)
+    ub <- .fmt(smc[i,6], digits_d, max.num[6])
+    est <- .fmt(smc[i,1], digits_d, max.num[1])
+    ste <- .fmt(smc[i,2], digits_d, max.num[2]+1)
     tvl <- .fmt(smc[i,3], 3, 8)
     pvl <- .fmt(smc[i,4], 3, 8)
-    lb <- .fmt(smc[i,5], digits.d, max.num[5])
-    ub <- .fmt(smc[i,6], digits.d, max.num[6])
+    lb <- .fmt(smc[i,5], digits_d, max.num[5])
+    ub <- .fmt(smc[i,6], digits_d, max.num[6])
     cat(rlb, est, ste, tvl, pvl, " ", lb, " ", ub, "\n")
   }
 
@@ -239,9 +254,9 @@ function(my.formula, data=d, rows=NULL,
   cat(rep(" ",13), OR.lbl, lb.lbl, ub.lbl, sep="", "\n")
   for (i in 1:(nrow(orci))) {
     rlb <- .fmtc(rownames(orci)[i], buf)
-    or.est <- .fmt(orci[i,1], digits.d, max.num)
-    lb <- .fmt(orci[i,2], digits.d, max.num)
-    ub <- .fmt(orci[i,3], digits.d, max.num)
+    or.est <- .fmt(orci[i,1], digits_d, max.num)
+    lb <- .fmt(orci[i,2], digits_d, max.num)
+    ub <- .fmt(orci[i,3], digits_d, max.num)
     cat(rlb, " ", or.est, " ", lb, " ", ub, "\n")
   }
 
@@ -280,7 +295,7 @@ function(my.formula, data=d, rows=NULL,
         m.d <- data.frame(Y, data)
       }
       else {
-        m.f <- my.formula
+        m.f <- my_formula
         m.d <- data
       }
 
@@ -305,18 +320,18 @@ function(my.formula, data=d, rows=NULL,
     else cat("\n>>> No collinearity analysis because not all variables are numeric.\n")
   }
  
-  if (res.rows > 0)
+  if (res_rows > 0)
     .logit3Residual(lm.out, nm, df.name,
-         n.vars, n.pred, n.obs, n.keep, digits.d, pre, line,
-         res.sort, res.rows, cooks.cut)
+         n.vars, n.pred, n.obs, n.keep, digits_d, pre, line,
+         res_sort, res_rows, cooks_cut)
  
   if (pred)
-    .logit4Pred(lm.out, nm, df.name, my.formula, brief, res.rows,
-         n.vars, n.pred, n.obs, n.keep, digits.d, pre, line,
-         new.data, pred, pred.all, 
-         numeric.all, in.data.frame, X1.new, 
-         X2.new, X3.new, X4.new, X5.new, X6.new,
-         pdf.file, width, height)
+    .logit4Pred(lm.out, nm, df.name, my_formula, brief, res_rows,
+         n.vars, n.pred, n.obs, n.keep, digits_d, pre, line,
+         new.data, pred, pred_all, 
+         numeric.all, in.data.frame, X1_new, 
+         X2_new, X3_new, X4_new, X5_new, X6_new,
+         pdf_file, width, height)
 
   invisible(lm.out)
 
