@@ -1,6 +1,6 @@
 .plt.bad <-
-function (x.miss, y.miss, stat, breaks, bin.start, n.row, n.col,
-          MD.cut, out.cut, fit.se, ...) {
+function (x.miss, y.miss, stat, breaks, bin_start, n_row, n_col,
+          MD.cut, out_cut, fit_se, ...) {
 
   # check for inconsistent parameters
   
@@ -9,14 +9,14 @@ function (x.miss, y.miss, stat, breaks, bin.start, n.row, n.col,
       "Must specify at least one variable to analyze\n\n")
   }
   
-  if (MD.cut > 0  &&  out.cut > 0) {
+  if (MD.cut > 0  &&  out_cut > 0) {
     cat("\n"); stop(call.=FALSE, "\n","------\n",
-      "Choose MD.cut or out.cut to specify outliers, but not both\n\n")
+      "Choose MD.cut or out_cut to specify outliers, but not both\n\n")
   }
   
-  if (fit.se[1] > 0.999) {
+  if (fit_se[1] > 0.999) {
     cat("\n"); stop(call.=FALSE, "\n","------\n",
-      "fit.se now specified as the confidence level, between 0 and 1\n\n")
+      "fit_se now specified as the confidence level, between 0 and 1\n\n")
   }
   
   if (stat %in% c("mean", "sd", "dev", "min", "median", "max") && y.miss) {
@@ -37,15 +37,15 @@ function (x.miss, y.miss, stat, breaks, bin.start, n.row, n.col,
       #"  with the Correlation function\n\n")
   #}
 
-  if (is.numeric(breaks) && !is.null(bin.start)) {
+  if (is.numeric(breaks) && !is.null(bin_start)) {
     cat("\n"); stop(call.=FALSE, "\n","------\n",
       "Choose only one option to specify a start value.\n",
-      "Either choose the option  breaks  or the option  bin.start.\n\n")
+      "Either choose the option  breaks  or the option  bin_start.\n\n")
   }
 
-  if (!is.null(n.row)  &&  !is.null(n.col)) {
+  if (!is.null(n_row)  &&  !is.null(n_col)) {
     cat("\n"); stop(call.=FALSE, "\n","------\n",
-      "Only specify n.row or n.col, but not both\n\n",
+      "Only specify n_row or n_col, but not both\n\n",
       "From one of the values, the other value is calculated\n\n")
   }
 
